@@ -57,11 +57,15 @@ class Mobyt(object):
                  return_credits=False,
                  sender=None,
                  order_id=None,
+                 allow_longer=False,
                  scheduled_delivery_time=None):
         """Sends an SMS"""
         if isinstance(recipients, str):
             recipients = [recipients]
 
+        if not allow_longer and len(message) > 160:
+            message = message[:160]
+
         data = {
             "message" : message,
             "message_type" : message_type,
@@ -70,6 +74,7 @@ class Mobyt(object):
             "sender": sender,
         }
 
+
         if scheduled_delivery_time:
             data['scheduled_delivery_time'] = scheduled_delivery_time
         
@@ -84,6 +89,8 @@ class Mobyt(object):
                         headers=headers,
                         data=json.dumps(data, default=json_serial))
 
+        print("DAdasdas")
+        print(r.text)
         r.raise_for_status()
 
         return r.json()
